@@ -4,6 +4,9 @@
 
 # import json
 # import shutil
+from datetime import timezone
+import time
+from datetime import datetime
 import gzip
 import json
 import os
@@ -63,17 +66,32 @@ def get_data(file_path, **kwargs):
     if 'dir_path' not in exclude:
         file_data['dir_path'] = os.path.dirname(file_path)
     if 'access_time' not in exclude:
-        file_data['access_time'] = os.path.getatime(file_path)
+        file_data['access_time'] = get_access_time(file_path)
     if 'modified_time' not in exclude:
-        file_data['modified_time'] = os.path.getmtime(file_path)
+        file_data['modified_time'] = get_modified_time(file_path)
     if 'created_time' not in exclude:
-        file_data['created_time'] = os.path.getctime(file_path)
+        file_data['created_time'] = get_create_time(file_path)
     if 'size' not in exclude:
         file_data['size'] = os.path.getsize(file_path)
 
     return file_data
 
 
+def get_modified_time(file_path):
+    mod_time = os.path.getmtime(file_path)
+    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
+
+
+def get_access_time(file_path):
+    mod_time = os.path.getatime(file_path)
+    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
+
+
+def get_create_time(file_path):
+    mod_time = os.path.getctime(file_path)
+    return int(datetime.fromtimestamp(mod_time).replace(tzinfo=timezone.utc).timestamp())
+
+
 def get_ext(file_path):
     file_name = os.path.basename(file_path)
     ext = os.path.splitext(file_name)
